@@ -9,6 +9,7 @@ from appconf import AppConf
 class DbTemplatesConf(AppConf):
     USE_CODEMIRROR = False
     USE_REVERSION = False
+    USE_TINYMCE = False
     ADD_DEFAULT_SITE = True
     AUTO_POPULATE_CONTENT = True
     MEDIA_PREFIX = None
@@ -40,3 +41,9 @@ class DbTemplatesConf(AppConf):
             raise ImproperlyConfigured("Please add 'reversion' to your "
                 "INSTALLED_APPS setting to make use of it in dbtemplates.")
         return value
+
+    def configure_use_tinymce(self, value):
+        if value and 'tinymce' not in settings.INSTALLED_APPS:
+            raise ImproperlyConfigured("Please add 'tinymce' to your "
+                "INSTALLED_APPS setting to make use of it in dbtemplates.")
+        return value
